# Guardian Security Service Dependencies
# Generated by ABI-Core scaffolding

# Security & Cryptography
cryptography>=41.0.0
cffi>=1.15.0

# Monitoring & Metrics
prometheus-client>=0.18.0

# Async Support
aiofiles>=23.2.0

# Logging & Audit
python-json-logger>=2.0.0

# ABI Core package
abi-core-ai>=1.9.1