{
  "service_id": "service://{{ project_name }}-webapp",
  "name": "{{ project_name }}-webapp",
  "description": "Web application for {{ project_name }}",
  "service_type": "webapp",
  "url": "http://{{ project_name }}-webapp:{{ web_port | default('8000') }}",
  "version": "1.0.0",
  "auth": {
    "method": "hmac_sha256",
    "key_id": "service://{{ project_name }}-webapp-default",
    "shared_secret": "{{ webapp_shared_secret | default('change-me-in-production') }}"
  },
  "actions": [
    "find_agent",
    "list_agents",
    "search_tool_registry"
  ],
  "checksum": "",
  "install_key": "service://{{ project_name }}-webapp@1.0.0",
  "origin": "{{ project_name }}",
  "metadata": {
    "domain": "{{ domain }}",
    "created_by": "abi-core-cli"
  }
}
